@@ -71,13 +71,13 @@ class ApoJWT():
                     raise ValueError("ApoJWT requires the token_finder attribute to be defined for validating JWTs")
                 try:
                     token = self.__token_f(*args, **kwargs)
-                    if token is None or token == "":
+                    if token is None or token == "" or token == "None":
                         raise Exception
                 except Exception as e:
                     if self.__exception_handler is None:
-                        raise jwt.exceptions.InvalidTokenError(f"JWT is missing - Token Finder failed: {e}")
+                        raise jwt.exceptions.InvalidTokenError("JWT is missing - Token Finder failed")
                     else:
-                        kwarg_dict = dict(token_data=dict(), token_subject="", token_permissions=list(), access_token="", code=401, msg=f"JWT is missing - Token Finder failed: {e}")
+                        kwarg_dict = dict(token_data=dict(), token_subject="", token_permissions=list(), access_token="", code=401, msg="JWT is missing - Token Finder failed")
                         self.__form_kwargs(self.__exception_handler, kwarg_dict, kwargs)
                         self.__exception_handler(*args, **kwargs)
                         raise NotImplementedError("ApoJWT Exception Handler must not return control")
@@ -93,13 +93,13 @@ class ApoJWT():
                     raise ValueError("ApoJWT requires the token_finder attribute to be defined for validating JWTs")
                 try:
                     token = self.__token_f(*args, **kwargs)
-                    if token is None or token == "":
+                    if token is None or token == "" or token == "None":
                         raise Exception
                 except Exception as e:
                     if self.__exception_handler is None:
-                        raise jwt.exceptions.InvalidTokenError(f"JWT is missing - Token Finder failed: {e}")
+                        raise jwt.exceptions.InvalidTokenError("JWT is missing - Token Finder failed")
                     else:
-                        kwarg_dict = dict(token_data=dict(), token_subject="", token_permissions=list(), access_token="", code=401, msg=f"JWT is missing - Token Finder failed: {e}")
+                        kwarg_dict = dict(token_data=dict(), token_subject="", token_permissions=list(), access_token="", code=401, msg="JWT is missing - Token Finder failed")
                         self.__form_kwargs(self.__exception_handler, kwarg_dict, kwargs)
                         self.__exception_handler(*args, **kwargs)
                         raise NotImplementedError("ApoJWT Exception Handler must not return control")
@@ -129,13 +129,13 @@ class ApoJWT():
                         raise TypeError("ApoJWT requires the token_finder attribute to be defined for validating JWTs")
                     try:
                         token = self.__token_f(*args, **kwargs)
-                        if token is None or token == "":
+                        if token is None or token == "" or token == "None":
                             raise Exception
                     except Exception as e:
                         if self.__exception_handler is None:
-                            raise jwt.exceptions.InvalidTokenError(f"JWT is missing - Token Finder failed: {e}")
+                            raise jwt.exceptions.InvalidTokenError("JWT is missing - Token Finder failed")
                         else:
-                            kwarg_dict = dict(token_data=dict(), token_subject="", token_permissions=list(), access_token="", code=401, msg=f"JWT is missing - Token Finder failed: {e}")
+                            kwarg_dict = dict(token_data=dict(), token_subject="", token_permissions=list(), access_token="", code=401, msg="JWT is missing - Token Finder failed")
                             self.__form_kwargs(self.__exception_handler, kwarg_dict, kwargs)
                             self.__exception_handler(*args, **kwargs)
                             raise NotImplementedError("ApoJWT Exception Handler must not return control")
@@ -165,13 +165,13 @@ class ApoJWT():
                         raise TypeError("ApoJWT requires the token_finder attribute to be defined for validating JWTs")
                     try:
                         token = self.__token_f(*args, **kwargs)
-                        if token is None or token == "":
+                        if token is None or token == "" or token == "None":
                             raise Exception
                     except Exception as e:
                         if self.__exception_handler is None:
-                            raise jwt.exceptions.InvalidTokenError(f"JWT is missing - Token Finder failed: {e}")
+                            raise jwt.exceptions.InvalidTokenError("JWT is missing - Token Finder failed")
                         else:
-                            kwarg_dict = dict(token_data=dict(), token_subject="", token_permissions=list(), access_token="", code=401, msg=f"JWT is missing - Token Finder failed: {e}")
+                            kwarg_dict = dict(token_data=dict(), token_subject="", token_permissions=list(), access_token="", code=401, msg="JWT is missing - Token Finder failed")
                             self.__form_kwargs(self.__exception_handler, kwarg_dict, kwargs)
                             self.__exception_handler(*args, **kwargs)
                             raise NotImplementedError("ApoJWT Exception Handler must not return control")
@@ -208,13 +208,13 @@ class ApoJWT():
                     kwargs.pop("refresh_data")
                 try:
                     ref_token = self.__refresh_f(*args, **kwargs)
-                    if ref_token is None or ref_token == "":
+                    if ref_token is None or ref_token == "" or ref_token == "None":
                         raise Exception
                 except Exception as e:
                     if self.__exception_handler is None:
-                        raise jwt.exceptions.InvalidTokenError(f"Refresh JWT is missing - Refresh Token Finder failed: {e}")
+                        raise jwt.exceptions.InvalidTokenError("Refresh JWT is missing - Refresh Token Finder failed")
                     else:
-                        kwarg_dict = dict(refresh_data=dict(), code=401, msg=f"Refresh JWT is missing - Refresh Token Finder failed: {e}")
+                        kwarg_dict = dict(refresh_data=dict(), code=401, msg="Refresh JWT is missing - Refresh Token Finder failed")
                         self.__form_kwargs(self.__exception_handler, kwarg_dict, kwargs)
                         self.__exception_handler(*args, **kwargs)
                         raise NotImplementedError("ApoJWT Exception Handler must not return control")
@@ -232,13 +232,13 @@ class ApoJWT():
                     kwargs.pop("refresh_data")
                 try:
                     ref_token = self.__refresh_f(*args, **kwargs)
-                    if ref_token is None or ref_token == "":
+                    if ref_token is None or ref_token == "" or ref_token == "None":
                         raise Exception
                 except Exception as e:
                     if self.__exception_handler is None:
-                        raise jwt.exceptions.InvalidTokenError(f"Refresh JWT is missing - Refresh Token Finder failed: {e}")
+                        raise jwt.exceptions.InvalidTokenError("Refresh JWT is missing - Refresh Token Finder failed")
                     else:
-                        kwarg_dict = dict(refresh_data=dict(), code=401, msg=f"Refresh JWT is missing - Refresh Token Finder failed: {e}")
+                        kwarg_dict = dict(refresh_data=dict(), code=401, msg="Refresh JWT is missing - Refresh Token Finder failed")
                         self.__form_kwargs(self.__exception_handler, kwarg_dict, kwargs)
                         self.__exception_handler(*args, **kwargs)
                         raise NotImplementedError("ApoJWT Exception Handler must not return control")
